#
# spec file for package uim
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _distconfdir}
%define _distconfdir %{_sysconfdir}
%endif
%define build_qt4 0%{?suse_version} <= 1500 && 0%{?sle_version} < 150300

Name:           uim
Version:        1.8.8
Release:        12.4
Summary:        A multilingual input method framework
License:        BSD-3-Clause AND LGPL-2.1-or-later AND (BSD-3-Clause OR LGPL-2.0-only)
Group:          System/I18n/Japanese
URL:            https://github.com/uim/uim
Source0:        https://github.com/uim/uim/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        suse-start-uim.el
Source2:        xemacs-auto-autoloads.el
Source3:        etc-x11-xim.d-uim
Source4:        baselibs.conf
Patch2:         uim-fix-crash-in-firefox.diff
Patch3:         bugzilla-1175274-emacs-27.1.patch
Patch4:         uim-fix-multiple_declaration.diff
Patch5:         riscv.patch
Patch6:         uim-gcc14-fix.patch
BuildRequires:  automake
BuildRequires:  emacs-x11
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  libtool
BuildRequires:  m17n-lib-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xemacs
%if %{build_qt4}
BuildRequires:  libqt4-devel
%endif
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(anthy)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libedit)
Recommends:     %{name}-gtk3 = %{version}
Recommends:     %{name}-qt5 = %{version}
Requires(pre):  %{_bindir}/touch

%description
Uim is a multilingual input method framework.

%package devel
Summary:        Development files for the UIM input method framework
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Include Files and Libraries mandatory for Development with uim.

%package gtk2
Summary:        GTK2 IM Module for UIM
Group:          System/I18n/Japanese
Requires:       %{name} = %{version}
%gtk2_immodule_requires

%description gtk2
Contains GTK+2.0 IM module for uim

%package gtk3
Summary:        GTK3 IM Module for UIM
Group:          System/I18n/Japanese
Requires:       %{name} = %{version}
%gtk3_immodule_requires

%description gtk3
Contains GTK+3.0 IM module for uim

%if %{build_qt4}
%package qt4
Summary:        Qt4 input module plugin for uim
Group:          System/I18n/Japanese
Requires:       %{name} = %{version}

%description qt4
Contains Qt4 input module plugin for uim
%endif

%package qt5
Summary:        Qt5 input module plugin for uim
Group:          System/I18n/Japanese
Requires:       %{name} = %{version}

%description qt5
Contains Qt5 input module plugin for uim

%prep
%setup -q
%patch -P 2 -p1
%patch -P 3 -p0
%patch -P 4 -p0
%patch -P 5 -p1
%patch -P 6 -p1
cp emacs/README README.emacs
iconv -f euc-jp -t utf-8 < emacs/README.ja > README.ja.emacs
./autogen.sh

%build
%configure --disable-static \
        --libexecdir=%{_prefix}/lib/uim \
        --with-anthy-utf8 \
%if %{build_qt4}
        --with-qt4 \
        --with-qt4-immodule \
%endif
        --with-qt5 \
        --with-qt5-immodule \
        --enable-kde-applet

make %{?_smp_mflags}

%install
%make_install
rm -f %{buildroot}%{_includedir}/gcroots.h
rm -f %{buildroot}%{_libdir}/pkgconfig/gcroots.pc
# this file is generated by "uim-module-manager".
# touch it here to make sure that it is in the file list of the
# package, then it will be deleted when the package is uninstalled:
touch %{buildroot}%{_datadir}/uim/modules
mkdir -p %{buildroot}%{_distconfdir}/X11/xim.d/ja
install -m 644 $RPM_SOURCE_DIR/etc-x11-xim.d-uim \
               %{buildroot}%{_distconfdir}/X11/xim.d/uim
pushd  %{buildroot}%{_distconfdir}/X11/xim.d/ja
    ln -s ../uim 60-uim
popd
# GNU Emacs:
install -m 644 $RPM_SOURCE_DIR/suse-start-uim.el %{buildroot}%{_datadir}/emacs/site-lisp/
pushd %{buildroot}%{_datadir}/emacs/site-lisp/uim-el
    sed -i 's/set-face-underline-p/set-face-underline/g' ./uim-var.el
    for i in $(find . -name "*.el")
    do
        emacs -no-site-file -q -batch -eval '(setq load-path (cons "." load-path))' -f batch-byte-compile $i
    done
popd
# XEmacs
mkdir -p %{buildroot}%{_datadir}/xemacs/site-packages/lisp/uim-el
install -m 644 emacs/*.el %{buildroot}%{_datadir}/xemacs/site-packages/lisp/uim-el
pushd %{buildroot}%{_datadir}/xemacs/site-packages/lisp/uim-el
    for i in $(find . -name "*.el")
    do
        xemacs -no-site-file -q -batch -eval '(setq load-path (cons "." load-path))' -f batch-byte-compile $i
    done
popd
install -m 644 $RPM_SOURCE_DIR/xemacs-auto-autoloads.el \
    %{buildroot}%{_datadir}/xemacs/site-packages/lisp/uim-el/auto-autoloads.el
# replace buildroot in comments in .elc files by spaces with the same total length:
BUILD_ROOT_REPLACEMENT=$(echo %{buildroot} | tr [:print:] ' ')
for i in $(find %{buildroot} -name "*.elc")
do
    perl -pi -e "s|(;;; from file )%{buildroot}(%{_datadir}/xemacs/site-packages/.*)|\1BUILD_ROOT_REPLACEMENT\2|" $i
    perl -pi -e "s|(;;; from file )%{buildroot}(%{_datadir}/emacs/site-lisp/.*)|\1BUILD_ROOT_REPLACEMENT\2|" $i
done
%find_lang uim
touch uim-chardict-qt.lang
%suse_update_desktop_file uim System SystemSetup
find %{buildroot} -name "*.scm" \
    | grep -E -v "installed-modules.scm|loader.scm" \
    | sort | uniq | perl -p -e "s|%{buildroot}||" >> uim.lang
%fdupes %{buildroot}%{_prefix}/share
find %{buildroot} -type f -name "*.la" -delete -print
rm -f doc/Makefile*

%post
/sbin/ldconfig
# register uim modules to uim. This will change the files:
#     %%{_datadir}/uim/installed-modules.scm
#     %%{_datadir}/uim/loader.scm
uim-module-manager --register \
    ajax-ime anthy anthy-utf8 byeoru elatin  hangul  ipa-x-sampa \
    latin m17nlib pyload skk tcode trycode tutcode viqr

%postun -p /sbin/ldconfig

%post gtk2
%gtk2_immodule_post

%postun gtk2
%gtk2_immodule_postun

%post gtk3
%gtk3_immodule_post

%postun gtk3
%gtk3_immodule_postun

%files -f uim.lang
%license COPYING
%doc AUTHORS NEWS* README*
%doc doc
%{_distconfdir}/X11/xim.d
%{_datadir}/uim
# autogenerated by uim-module-manager:
%ghost %{_datadir}/uim/installed-modules.scm
%ghost %{_datadir}/uim/loader.scm
%ghost %{_datadir}/uim/modules
%{_bindir}/uim-sh
%{_bindir}/uim-module-manager
%{_bindir}/uim-xim
%{_bindir}/uim-fep
%{_bindir}/uim-fep-tick
%{_bindir}/uim-el-agent
%{_bindir}/uim-el-helper-agent
%{_bindir}/uim-help
%{_bindir}/uim-m17nlib-relink-icons
%{_libdir}/*.so.*
%dir %{_libdir}/uim
%if "%{_libdir}" != "%{_prefix}/lib"
%dir %{_prefix}/lib/uim
%endif
%{_prefix}/lib/uim/uim-helper-server
%dir %{_libdir}/uim/plugin/
%{_libdir}/uim/plugin/*.so
%doc %{_mandir}/man1/*.1.gz
%{_datadir}/applications/%{name}.desktop
%{_datadir}/emacs/site-lisp/*
%{_datadir}/xemacs/site-packages

%files devel
%{_libdir}/*.so
%{_includedir}/uim/
%{_libdir}/pkgconfig/uim.pc

%files gtk2
%{_bindir}/uim-*-gtk
%{_bindir}/uim-*-gtk-*
%{_bindir}/uim-input-pad-ja
%{_prefix}/lib/uim/uim-*-gtk
%{_libdir}/gtk-2*/*/immodules/*.so

%files gtk3
%{_bindir}/uim-*-gtk3
%{_bindir}/uim-*-gtk3-*
%{_prefix}/lib/uim/uim-*-gtk3
%{_libdir}/gtk-3*/*/immodules/*.so

%if %{build_qt4}
%files qt4 -f uim-chardict-qt.lang
%{_bindir}/uim-*-qt4
%{_prefix}/lib/uim/uim-*-qt4
%{_libdir}/qt4/plugins/inputmethods/*.so
%endif

%files qt5 -f uim-chardict-qt.lang
%{_bindir}/uim-*-qt5
%{_prefix}/lib/uim/uim-*-qt5
%{_libdir}/qt5/plugins/platforminputcontexts/*.so

%changelog
* Wed Aug 28 2024 Takashi Iwai <tiwai@suse.com>
- Fix build errors with gcc14:
  uim-gcc14-fix.patch
  also run autogen.sh to refresh
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Aug 21 2023 Marguerite Su <i@marguerite.su>
- set-face-underline-p is an alias to set-face-underline
  and was deprecated since emacs 24.3
* Mon Aug  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop canna support: canna has not been maintained for a long time
  and sec issues are not being addressed (bsc#1199280).
* Thu Jan 20 2022 tiwai@suse.de
- Adjust xim.d script for KDE Plasma (boo#1194916)
* Thu Oct 14 2021 Dr. Werner Fink <werner@suse.de>
- Correct quotation of the anonymous function "(lambda)"
* Thu Dec 10 2020 Antonio Larrosa <alarrosa@suse.com>
- Do not build the qt4 subpackage for Leap 15.3 or newer
  (boo#1179613).
* Thu Nov 26 2020 tiwai@suse.de
- Move the startup snippet to /usr/etc/X11/xim.d for TW
* Fri Aug 21 2020 Andreas Schwab <schwab@suse.de>
- riscv.patch: Add support for RISC-V to libgcroots
* Tue Aug 18 2020 Dr. Werner Fink <werner@suse.de>
- Add patch uim-fix-multiple_declaration.diff to avoid multiple
  declaration of GCROOTS_jmp_buf
* Tue Aug 18 2020 Dr. Werner Fink <werner@suse.de>
- Add patch bugzilla-1175274-emacs-27.1.patch
  There is no (process-kill-without-query) anymore, use
  (set-process-query-on-exit-flag) instead (boo#1175274).
* Sat Apr 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Stop packaging the Qt4 frontend for openSUSE Factory.
  Qt4 is EOL and will be removed from future openSUSE releases.
* Fri May 18 2018 jengelh@inai.de
- Remove future goals from description.
- Fix copypasted subpackage package summary.
- Drop useless --with-pic, no static libs are built.
* Thu May 10 2018 aloisio@gmx.com
- Update to version 1.8.8
  Fixes:
  * Fix a build error with --with-libgcroots=installed
    + [GitHub #130][Reported by HIGUCHI Daisuke]
  * uim-qt5
    + Fix a build error
    [GitHub #129][Reported by HIGUCHI Daisuke]
  version 1.8.7
  Fixes:
  * uim-skk
    + Fix a socket clean bug
    [GitHub#32][Reported by HIGUCHI Daisuke]
    + Fix wrong close call
    [GitHub#55][Patch by zephyrus00jp]
  * uim-qt4
    + Add a missing include
    [GitHub#38][Patch by Raphael Kubo da Costa]
  * uim.el
    + Fix a bug that other minor mode key bindings are ignored
    on Emacs 24
    [GitHub#51][Reported by Araeos]
    + Fix a bug that Shift+Arrow doesn't work
    [GitHub#116][Reported by Vladimir Panteleev]
  * uim-gtk3
    + Fix a bug that the candidate windows isn't shown
    [GitHub#76][Patch by Konosuke Watanab]
  Enhancements:
  * all
    + Add "Keywords" to .desktop
    [GitHub#57][Patch by HIGUCHI Daisuke]
  * uim-gtk
    + Improve GTK+ 3 support
    [GitHub#35][Patch by e-kato]
    + Support libpanel-applet 3.14 or later
    [GitHub#48][Patch by Dmitry Shachnev]
    + Support Wayland backend
    [GitHub#71][Reported by Thibaut Girka]
  * uim-fep
    + Use UTF-8 for comment encoding
    [GitHub#46][Patch by Felix Janda]
  * uim-qt5
    + Make workable
  * uim-social-ime
    + Remove because the service was disruption
  * uim.el
    + Support autoload
    [GitHub#121][Patch by Arun Isaac]
- Added qt5 subpackage
- Dropped applet-gnome subpackage (no longer supported on current
  targets)
- Dropped fix-for-sles-qhash-incomplete-type.patch (no longer
  necessary)
- Dropped libgcroots-aarch64.patch (merged upstream)
- Spec cleanup
* Sun Sep 28 2014 ftake@geeko.jp
- Drop locale(ja) to slim down Japanese locale
* Fri Feb 14 2014 tiwai@suse.de
- Fix *-32bit post and postun calls for gtk-query-immodules-2 on
  openSUSE 13.1 and later (bnc#845860)
* Sat Aug 24 2013 ftake@geeko.jp
- update to 1.8.6
  * libuim: add XDG_RUNTIME_DIR support (by tagoh)
  * po: list language names on each line in LINGUAS (by naota)
  * uim-canna: Avoid a crash when a Canna server name is specified
    (by Kouichi ONO)
  * uim-m17nlib: Add an option to set a candidate windows to be
    visiable or hidden
  * uim-tutcode: Updated trycode composition table retrieved
    2013-06-26
* Wed Aug 21 2013 dimstar@opensuse.org
- Introduce build_applet defines, set to true up to openSUSE 12.3:
  + Specifies wether to build the gnome-panel applet, resp
    uim-applet-gnome subpackage.
  + Conditionally BuildRequires gnome-panel-devel
  + If evaluated to false, obsoletes uim-applet-gnome for clean
    upgrades.
* Tue Jul 16 2013 coolo@suse.com
- remove qt3 support, long dead
* Tue May  7 2013 schwab@suse.de
- libgcroots-aarch64.patch: Add support for aarch64 in libgcroots
- Don't regenerate configure
* Tue Apr 30 2013 cfarrell@suse.com
- license update: BSD-3-Clause and LGPL-2.1+ and (BSD-3-Clause or LGPL-2.0)
  More detail on license choices. Compatible with Fedora spec file
  declaration
* Sat Apr 27 2013 i@marguerite.su
- update version 1.8.5
  * uim-gtk2/3
  * * Avoid an infinite recursion when no preedit is started (by tagoh)
  * uim-tutcode
  * * Fix behavior of postfix katakana conversion
- specfile clean
* Mon Jul  2 2012 i@marguerite.su
- update version 1.8.1
  * New IM uim-google-cgiapi-jp
  * New IM uim-baidu-olime-jp
  * Delay showing candidate window
  * Horizontal candidate window
  * Japanese Romaji-Kana composing rule in uim-pref
  * Many new features in uim-tutcode
* Tue Jun  5 2012 i@marguerite.su
- fix sles builds.
  * %%make_install to %%makeinstall
* Tue Feb 28 2012 tiwai@suse.de
- updated uim to 1.7.2, 1.7.3
  * Fix crash when text acquisition is invoked with selected text
  * Support text acquisition API with QTextEdit of Qt4
  * Fix behavior of text deletion API with QTextEdit of Qt4
  * Bug fixes for uim-m17nlib
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Oct 13 2011 tiwai@suse.de
- Add missing obsoletes/provides for uim-qt3 in baselibs.conf
- Fix crash and a registration issue in Firefox (bnc#723899)
* Wed Oct 12 2011 anixx@opensuse.org
- enable kde3 applet
- rename uim-qt to uim-qt3
- remove obsolete version check
* Mon Sep  5 2011 coolo@suse.com
- fix build with newer ld
* Mon Sep  5 2011 nlminhtl@gmail.com
- uim doesn't depend on libgnomeui-devel from 1.7.0.
  The dependency was removed in r6932 in the upstream repository
* Mon Aug  8 2011 tiwai@suse.de
- Fix baselibs.conf to update GTK immodule cache properly for
  uim-gtk2-32bit and uim-gtk3-32bit packages, too
* Fri Jul 29 2011 tiwai@suse.de
- updated to uim-1.7.1:
  Major updates, see release notes of 1.6.0, 1.6.1, 1.7.0 and
  1.7.1:
    http://uim.googlecode.com/svn/tags/uim-1.6.0/RELNOTE
    http://uim.googlecode.com/svn/tags/uim-1.6.1/RELNOTE
    http://uim.googlecode.com/svn/tags/uim-1.7.0/RELNOTE
    http://uim.googlecode.com/svn/tags/uim-1.7.1/RELNOTE
- Enabled Gtk3 IM build
- Re-enabled applet build for FACTORY, created uim-applet-gnome
  sub-package
- Enable libedit properly
- Enable m17n-lib
- Clean up spec file
* Tue May 31 2011 dimstar@opensuse.org
- Introduce a build_applet define, which is set to 1 on openSUSE up
  to 11.4. For current Factory, we need to disable the applet, as
  it is not (yet) ported to the new libpanelapplet-4.0
  infrastructure of Gnome3.
- Move the gnome applet actually to the gtk package (when building
  the applet).
* Wed Mar  9 2011 tiwai@suse.de
- Fix post scripts to use new gtk2_immodule_* macros (bnc#678080)
- Fix builds with older distros
* Fri Jan 14 2011 coolo@novell.com
- fix build and ran spec-cleaner
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Tue Sep 15 2009 crrodriguez@novell.com
- do not package static libraries
* Thu Jul  9 2009 tiwai@suse.de
- removed unused patches
* Thu Jul  2 2009 tiwai@suse.de
- updated to version 1.5.6:
  * lots of changes, see
    http://uim.googlecode.com/svn/tags/uim-1.5.6/NEWS
- enable qt4 immodule
- enable anthy-utf8 IM
* Thu Jun  4 2009 tiwai@suse.de
- fix build for older distros
* Sun Feb 22 2009 vuntz@novell.com
- Add uim-fix-gnome-compilation.patch to fix build. The patch
  should probably be sent upstream if the latest version still has
  the issue (upstream is at 1.5.5 now).
- Add libgnomeui-devel BuildRequires for the patch.
* Tue Nov 25 2008 sbrabec@suse.cz
- Supplement gtk2-32bit/gtk2-64bit and qt3-32bit/qt3-64bit in
  baselibs.conf (bnc#354164).
* Fri Oct 17 2008 mfabian@suse.de
- bnc#436245: Emacs cannot start flawlessly from within a directory
  containing umlauts in it's name: fix by loading uim-leim
  not immediately in suse-start-uim.el but rather load it in
  'emacs-startup-hook.
  (Fixed by Werner Fink <werner@suse.de>).
- fix build in Factory (add “intltoolize --force -c --automake”)
* Fri Jan 11 2008 mfabian@suse.de
- include missing headers to make it build on STABLE.
- use fdupes
* Mon May  7 2007 mfabian@suse.de
- Bugzilla #271696: fix bug in uim start script which made it
  impossible to set uim as the default input method.
  Thanks to Satoshi Niimi <sa2c@sa2c.net> for the report and the
  fix.
* Sat Mar 31 2007 aj@suse.de
- Cleanup BuildRequires.
* Mon Feb  5 2007 ro@suse.de
- fix build
* Fri Feb  2 2007 sbrabec@suse.cz
- Removed references to /opt/gnome.
- Bi-arch libexecdir fix.
- Package each file only once.
- Use %%ghost for autogenerated files.
* Mon Dec 25 2006 schwab@suse.de
- Fix format string bugs.
- Make uim-el less chatty.
- Remove inappropriate advice.
- Don't clobber current-input-method-title.
* Fri Sep 15 2006 mfabian@suse.de
- make auto-autoloads.el for XEmacs really work.
- make vertical candidate list display the default.
* Thu Sep 14 2006 mfabian@suse.de
- add uim-el for XEmacs.
- byte-compile the .el files for Emacs and XEmacs.
- add suse-start-uim.el for Emacs and auto-autoloads.el for XEmacs
  to be able to use uim-el without further setup.
* Mon Sep 11 2006 mfabian@suse.de
- update to 1.2.1.
- new subpackage uim-qt (used to be build from a different
  tarball but it is now included in uim).
* Mon Jun 19 2006 schwab@suse.de
- Work around broken use of configure substitutions.
* Tue Feb 28 2006 mfabian@suse.de
- add "Provides: locale(...)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 schwab@suse.de
- Fix garbage collector.
- Use RPM_OPT_FLAGS.
- Fix aliasing bugs.
* Fri Aug 26 2005 mfabian@suse.de
- Bugzilla #113081: uim should register the input modules in the
  %%post script.
* Thu Aug 25 2005 mfabian@suse.de
- Bugzilla #112931: gtk2 specific stuff in %%post and %%postun should
  be moved to the proper sub-package.
* Mon Aug  8 2005 mfabian@suse.de
- update to 0.4.8.
* Tue May 31 2005 mfabian@suse.de
- update to 0.4.6 svn revison 850.
  remove ipa-x-sampa.patch (included).
* Mon Apr 25 2005 mfabian@suse.de
- update to 0.4.6 svn revision 828.
- fix a small problem in ipa-x-sampa: mnenonic for U+02D0 and
  U+02D1 is ':' and ':\' respectively (not ';' and ';\').
* Thu Feb 24 2005 mfabian@suse.de
- Bugzilla #66448: update to 0.4.6 svn revision 714
  to fix a security problem (CAN-2005-0503).
* Tue Feb 22 2005 mfabian@suse.de
- fix typo in /etc/X11/xim.d/uim.
* Tue Feb 22 2005 mfabian@suse.de
- create start script /etc/X11/xim.d/uim and symlink in ja
  subdirectory.
* Sat Jan  8 2005 mfabian@suse.de
- update to 0.4.5.20050108.165 (fixes crashes and moves the plugins
  to the correct directory).
- add anthy, anthy-devel to "# neededforbuild". Previously anthy
  was not needed at buildtime but now it is.
- remove dont-use-uim-default-by-default-for-all-languages.patch,
  it's not necessary anymore and setting the wildcard for the
  direct input method to the  empty string instead of "*" makes
  uim crash.
* Fri Jan  7 2005 mfabian@suse.de
- update to 0.4.5.20050107.
- remove uim-toolbar-gtk.patch (now included in tarball).
* Tue Jan  4 2005 mfabian@suse.de
- update prime.scm to prime_2004-12-13.scm.
* Wed Dec 22 2004 mfabian@suse.de
- apply uim-toolbar-gtk.patch received from
  TOKUNAGA Hiroyuki <tkng@xem.jp> to make uim-toolbar-gtk work
  with gtk+ >= 2.5.
* Fri Dec 17 2004 mfabian@suse.de
- fix version number in configure.ac.
* Wed Dec 15 2004 mfabian@suse.de
- update to 0.4.5svn1650.
  dont-use-uim-default-by-default-for-all-languages.patch is
  apparently not necessary anymore.
* Thu Sep 16 2004 ro@suse.de
- remove xfce from neededforbuild (unused anyway)
* Sat Sep  4 2004 mfabian@suse.de
- update to 0.4.3.
* Tue Aug 24 2004 mfabian@suse.de
- Bugzilla #44155: add /usr/bin/touch to PreReq:.
* Fri Aug 20 2004 mfabian@suse.de
- update to svn trunk (0.4.2.1.20040820) to fix the switching
  between the romaji and kana input mode, see also:
  http://freedesktop.org/pipermail/uim/2004-August/000603.html
* Fri Aug 13 2004 mfabian@suse.de
- update to 0.4.2.1
- add control-reaches-end-of-non-void-function.patch.
- move uim-helper-candwin-gtk, uim-helper-toolbar-gtk, and
  uim-helper-applet to uim-applet sub-package.
* Tue Mar 16 2004 mfabian@suse.de
- update to 0.3.2.
* Tue Mar 16 2004 mfabian@suse.de
- make only uim-anthy a default gtk-input-module for Japanese.
- don't use the uim-default input module for any language by
  default (This module was used for *all* languages by default,
  that means even when running in de_DE.UTF-8 locale,
  uim-helper-server would start, which is quite useless).
- add canna canna-devel canna-libs to # neededforbuild in order
  to build the uim-canna module as well.
* Fri Mar  5 2004 mfabian@suse.de
- update to 0.3.1
- remove uim.patch and warnings.patch (included upstream).
* Thu Feb 26 2004 mfabian@suse.de
- new package, version 0.3.0.1.
